@@ -7,7 +7,7 @@ use Carp::Clan qw/^DBIx::Class/;
 use Text::Balanced qw( extract_bracketed );
 use Class::C3;
 
-our $VERSION = '0.03999_01';
+our $VERSION = '0.03999_02';
 
 =head1 NAME
 
@@ -62,7 +62,7 @@ sub _sqlite_parse_table {
     $sth->finish;
 
     # Cut "CREATE TABLE ( )" blabla...
-    $sql =~ /^[\w\s]+\((.*)\)$/si;
+    $sql =~ /^[\w\s']+\((.*)\)$/si;
     my $cols = $1;
 
     # strip single-line comments
@@ -167,6 +167,7 @@ sub _tables_list {
     my @tables;
     while ( my $row = $sth->fetchrow_hashref ) {
         next unless lc( $row->{type} ) eq 'table';
+        next if $row->{tbl_name} =~ /^sqlite_/;
         push @tables, $row->{tbl_name};
     }
     $sth->finish;
